@@ -4,7 +4,8 @@ from tensorflow.keras.models import Model
 from tensorflow.keras.layers import Layer
 
 from leap_model_rebuilder.modelexpander import expand_model
-from leap_model_rebuilder.utils import is_custom_layers, convert_subclassed_to_functional, should_replace_layers
+from leap_model_rebuilder.utils import is_custom_layers, convert_subclassed_to_functional, should_replace_layers, \
+    is_lambda_layers
 
 
 def rebuild_model(model: Model, input_tensor_shape: Optional[Tuple[int, ...]] = None,
@@ -25,7 +26,7 @@ def rebuild_model(model: Model, input_tensor_shape: Optional[Tuple[int, ...]] =
         layer_replacement_dict = {}
     if input_tensor_shape is not None:
         model = convert_subclassed_to_functional(model, input_tensor_shape)
-    while is_custom_layers(model) or should_replace_layers(model, layer_replacement_dict):
+    while is_custom_layers(model) or is_lambda_layers(model) or should_replace_layers(model, layer_replacement_dict):
         model = expand_model(model, layer_replacement_dict)
 
     return model
